.. Django Manifest documentation master file.

Welcome to Django Manifest's documentation!
==========================================

A kickstarter for Django Web Framework projects that supports both legacy frontend and javascript technolohies using REST API.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   manual_project_creation
   manual_frontend_integration


.. toctree::
   :maxdepth: 2
   :caption: Modules:

   modules


.. toctree::
   :maxdepth: 2
   :caption: Tests:

   tests

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
